@@ -13,6 +13,7 @@ from collections import OrderedDict
 import re
 import uuid
 import functools
+import json
 
 from dateutil.parser import parse
 
@@ -89,12 +90,16 @@ class Base(abc.ABC):
 
     _camel_to_snake_re = re.compile(r'(?<!^)(?=[A-Z])')
 
-    def __init__(self, data):
+    def __init__(self, data, strict=False):
         self.fields = []
         self.key_transform_lookup = {}
         for key, value in data.items():
             self.fields.append(key)
-            setattr(self, Base._from_api_conversion(key), value)
+            try:
+                setattr(self, Base._from_api_conversion(key), value)
+            except AttributeError:
+                if strict:
+                    raise
 
     def __eq__(self, other):
         if isinstance(other, type(self)):
@@ -217,6 +222,23 @@ class Player(Base):
         players = chronicler.get_player_updates(ids=id_, order=order)
         return [cls(dict(p['data'], timestamp=p['firstSeen'])) for p in players]
 
+    @classmethod
+    def load_all_by_gameday(cls, season, day):
+        """
+        Returns dict of all players and their fk stats on the given season/day. 1-indexed.
+        """
+        players = reference.get_all_players_for_gameday(season, day)
+        return {
+            player['player_id']: cls(player) for player in players
+        }
+
+    @classmethod
+    def load_by_gameday(cls, id_, season, day):
+        """
+        Returns one player and their fk stats on the given season/day. 1-indexed.
+        """
+        return cls.load_all_by_gameday(season, day).get(id_)
+
     @classmethod
     def find_by_name(cls, name):
         """
@@ -280,9 +302,7 @@ class Player(Base):
                 ((self.thwackability * self.divinity) ** 0.35) *
                 ((self.moxie * self.musclitude) ** 0.075) * (self.martyrdom ** 0.02))
 
-    @property
-    def batting_rating(self):
-        return self.hitting_rating
+    batting_rating = hitting_rating
 
     @Base.lazy_load("_pitching_rating", use_default=False)
     def pitching_rating(self):
@@ -533,6 +553,22 @@ class Player(Base):
 
         return Player(original_json)
 
+    @property
+    def player_name(self):
+        return self.name
+
+    @player_name.setter
+    def player_name(self, v):
+        self.name = v
+
+    @property
+    def player_id(self):
+        return self.id
+
+    @player_id.setter
+    def player_id(self, v):
+        self.id = v
+
 
 class Team(Base):
     """
@@ -964,8 +1000,56 @@ class Game(Base):
 
 
 class Fight(Game):
-    """Represents a Blaseball boss fight. Currently unimplemented."""
-    pass  # will probably need this eventually.
+    """Represents a Blaseball boss fight."""
+
+    class DamageResults(Base):
+        """
+        Information regarding a specific damage event
+        """
+        @Base.lazy_load("_dmg_type")
+        def dmg_type(self):
+            return tables.DamageType(self._dmg_type)
+
+        @Base.lazy_load("_player_source_id", cache_name="_player_source")
+        def player_source(self):
+            return Player.load_one(self._player_source_id)
+
+        @Base.lazy_load("_team_target_id", cache_name="_team_target")
+        def team_target(self):
+            return Team.load(self._team_target_id)
+
+    @classmethod
+    def load_by_id(cls, id_):
+        fights = chronicler.get_fights(id_=id_)
+        if len(fights) != 1:
+            return None
+        return cls(fights[0]["data"])
+
+    @classmethod
+    def load_by_season(cls, season):
+        return {
+            x['id']: cls(x["data"]) for x in chronicler.get_fights(season=season)
+        }
+
+    @Base.lazy_load("_away_hp")
+    def away_hp(self):
+        return int(self._away_hp)
+
+    @Base.lazy_load("_home_hp")
+    def home_hp(self):
+        return int(self._home_hp)
+
+    @Base.lazy_load("_away_max_hp")
+    def away_max_hp(self):
+        return int(self._away_max_hp)
+
+    @Base.lazy_load("_home_max_hp")
+    def home_max_hp(self):
+        return int(self._home_max_hp)
+
+    @Base.lazy_load("_damage_results_str", cache_name="_damage_results", default_value=list())
+    def damage_results(self):
+        return [self.DamageResults(x) for x in json.loads(self._damage_results_str)]
 
 
 class DecreeResult(Base):
